#!/bin/sh

# 定义目录和文件路径
TARGET_DIR="/usr/share/openwebui"
OPENWEBUI_TAR="$TARGET_DIR/openwebui.tar"
OLLAMA_TAR="$TARGET_DIR/ollama.tar"
OPENWEBUI_IMAGE="harbor.spacemit.com/application/openwebui-image:latest"
OLLAMA_IMAGE="harbor.spacemit.com/application/ollama-image:latest"

# 创建目标目录（如果不存在）
if [ ! -d "$TARGET_DIR" ]; then
    mkdir -p "$TARGET_DIR"
fi

# 检测是否需要下载和加载 openwebui.tar
if [ -f "$OPENWEBUI_TAR" ]; then
    echo "文件 openwebui.tar 已存在，跳过下载。"
else
    echo "文件 openwebui.tar 不存在，开始下载。"
    wget -P "$TARGET_DIR" https://archive.spacemit.com/spacemit-ai/openwebui/openwebui.tar
fi

# 检查 openwebui 镜像是否已加载
if docker image inspect "$OPENWEBUI_IMAGE" >/dev/null 2>&1; then
    echo "镜像 $OPENWEBUI_IMAGE 已加载，跳过加载。"
else
    echo "镜像 $OPENWEBUI_IMAGE 未加载，开始加载镜像。"
    docker load -i "$OPENWEBUI_TAR"
fi

# 检测是否需要下载和加载 ollama.tar
if [ -f "$OLLAMA_TAR" ]; then
    echo "文件 ollama.tar 已存在，跳过下载。"
else
    echo "文件 ollama.tar 不存在，开始下载。"
    wget -P "$TARGET_DIR" https://archive.spacemit.com/spacemit-ai/openwebui/ollama.tar
fi

# 检查 ollama 镜像是否已加载
if docker image inspect "$OLLAMA_IMAGE" >/dev/null 2>&1; then
    echo "镜像 $OLLAMA_IMAGE 已加载，跳过加载。"
else
    echo "镜像 $OLLAMA_IMAGE 未加载，开始加载镜像。"
    docker load -i "$OLLAMA_TAR"
fi

# 启动 Docker Compose 服务
cd "$TARGET_DIR" || exit 1
docker compose up -d
